%%%Additional Information GUI
function varargout = AdditionalInformation(varargin)
% AdditionalInformation M-file for AdditionalInformation.fig
%      AdditionalInformation, by itself, creates a new AdditionalInformation or raises the existing
%      singleton*.
%
%      H = AdditionalInformation returns the handle to a new AdditionalInformation or the handle to
%      the existing singleton*.
%
%      AdditionalInformation('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in AdditionalInformation.M with the given input arguments.
%
%      AdditionalInformation('Property','Value',...) creates a new AdditionalInformation or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before AdditionalInformation_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to AdditionalInformation_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help AdditionalInformation

% Last Modified by GUIDE v2.5 21-May-2011 10:44:15

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @AdditionalInformation_OpeningFcn, ...
                   'gui_OutputFcn',  @AdditionalInformation_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before AdditionalInformation is made visible.
function AdditionalInformation_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to AdditionalInformation (see VARARGIN)

% Choose default command line output for AdditionalInformation
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes AdditionalInformation wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = AdditionalInformation_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in GoToPoltPhen2.
function GoToPoltPhen2_Callback(hObject, eventdata, handles)
% hObject    handle to GoToPoltPhen2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
web http://genetics.bwh.harvard.edu/pph2/

% --- Executes on button press in GoToConSurf.
function GoToConSurf_Callback(hObject, eventdata, handles)
% hObject    handle to GoToConSurf (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
web http://consurf.tau.ac.il/index_nucleotides.php

% --- Executes on button press in GoToTMpred.
function GoToTMpred_Callback(hObject, eventdata, handles)
% hObject    handle to GoToTMpred (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
web http://www.ch.embnet.org/software/TMPRED_form.html

% --- Executes on button press in GoToOMIM.
function GoToOMIM_Callback(hObject, eventdata, handles)
% hObject    handle to GoToOMIM (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
web http://www.ncbi.nlm.nih.gov/omim/

% --- Executes on button press in GoToUCSC.
function GoToUCSC_Callback(hObject, eventdata, handles)
% hObject    handle to GoToUCSC (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
web http://genome.cse.ucsc.edu/index.html?org=Human&db=hg19&hgsid=195937859

% --- Executes during object creation, after setting all properties.
function GoToConSurf_CreateFcn(hObject, eventdata, handles)
% hObject    handle to GoToConSurf (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes during object creation, after setting all properties.
function GoToTMpred_CreateFcn(hObject, eventdata, handles)
% hObject    handle to GoToTMpred (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes during object creation, after setting all properties.
function GoToOMIM_CreateFcn(hObject, eventdata, handles)
% hObject    handle to GoToOMIM (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes during object creation, after setting all properties.
function GoToUCSC_CreateFcn(hObject, eventdata, handles)
% hObject    handle to GoToUCSC (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes during object creation, after setting all properties.
function axes1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to axes1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called
imshow('AdditionalInfo.jpg',[])
axis image

% Hint: place code in OpeningFcn to populate axes1
